@@ -254,6 +254,8 @@ devSet <- function(which=dev.next(), ...) {
   if (!is.numeric(which) || length(which) != 1L) {
     if (length(which) != 1L || !is.character(which)) {
       require("digest") || throw("Package not loaded: digest");
+      # To please R CMD check
+      digest <- NULL; rm(list="digest");
       which <- digest(which);
     }
 
