@@ -28,14 +28,14 @@
 # }
 #
 # \usage{
-#   toBMP(name, ..., field=getOption("devEval/args/field", "fullname"))
-#   toEMF(name, ..., ext="emf", field=getOption("devEval/args/field", "fullname"))
-#   toPDF(name, ..., field=getOption("devEval/args/field", "fullname"))
-#   toPNG(name, ..., field=getOption("devEval/args/field", "fullname"))
-#   toSVG(name, ..., field=getOption("devEval/args/field", "fullname"))
-#   toTIFF(name, ..., field=getOption("devEval/args/field", "fullname"))
-#   toWMF(name, ..., ext="wmf", field=getOption("devEval/args/field", "fullname"))
-#   %% toCairoPNG(name, ..., field=getOption("devEval/args/field", "fullname"))
+#   toBMP(name, ..., field=getOption("devEval/args/field", "pathname"))
+#   toEMF(name, ..., ext="emf", field=getOption("devEval/args/field", "pathname"))
+#   toPDF(name, ..., field=getOption("devEval/args/field", "pathname"))
+#   toPNG(name, ..., field=getOption("devEval/args/field", "pathname"))
+#   toSVG(name, ..., field=getOption("devEval/args/field", "pathname"))
+#   toTIFF(name, ..., field=getOption("devEval/args/field", "pathname"))
+#   toWMF(name, ..., ext="wmf", field=getOption("devEval/args/field", "pathname"))
+#   %% toCairoPNG(name, ..., field=getOption("devEval/args/field", "pathname"))
 #
 #   toFavicon(..., name="favicon", type="png", width=32L, height=width,
 #                  par=list(mar=c(0,0,0,0), bg="transparent"))
@@ -78,39 +78,39 @@
 # @keyword device
 # @keyword utilities
 #*/###########################################################################
-toBMP <- function(name, ..., field=getOption("devEval/args/field", "fullname")) {
+toBMP <- function(name, ..., field=getOption("devEval/args/field", "pathname")) {
   devEval(type="bmp", name=name, ..., field=field);
 }
 
-toEMF <- function(name, ..., ext="emf", field=getOption("devEval/args/field", "fullname")) {
+toEMF <- function(name, ..., ext="emf", field=getOption("devEval/args/field", "pathname")) {
   devEval(type="win.metafile", name=name, ..., ext=ext, field=field);
 }
 
-toWMF <- function(name, ..., ext="wmf", field=getOption("devEval/args/field", "fullname")) {
+toWMF <- function(name, ..., ext="wmf", field=getOption("devEval/args/field", "pathname")) {
   devEval(type="win.metafile", name=name, ..., ext=ext, field=field);
 }
 
-toEPS <- function(name, ..., field=getOption("devEval/args/field", "fullname")) {
+toEPS <- function(name, ..., field=getOption("devEval/args/field", "pathname")) {
   devEval(type="eps", name=name, ..., field=field);
 }
 
-toPDF <- function(name, ..., field=getOption("devEval/args/field", "fullname")) {
+toPDF <- function(name, ..., field=getOption("devEval/args/field", "pathname")) {
   devEval(type="pdf", name=name, ..., field=field);
 }
 
-toPNG <- function(name, ..., field=getOption("devEval/args/field", "fullname")) {
+toPNG <- function(name, ..., field=getOption("devEval/args/field", "pathname")) {
   devEval(type="png", name=name, ..., field=field);
 }
 
-toSVG <- function(name, ..., field=getOption("devEval/args/field", "fullname")) {
+toSVG <- function(name, ..., field=getOption("devEval/args/field", "pathname")) {
   devEval(type="svg", name=name, ..., field=field);
 }
 
-toTIFF <- function(name, ..., field=getOption("devEval/args/field", "fullname")) {
+toTIFF <- function(name, ..., field=getOption("devEval/args/field", "pathname")) {
   devEval(type="tiff", name=name, ..., field=field);
 }
 
-## toCairoPNG <- function(name, ..., field=getOption("devEval/args/field", "fullname")) {
+## toCairoPNG <- function(name, ..., field=getOption("devEval/args/field", "pathname")) {
 ##   devEval(type="CairoPNG", name=name, ..., field=field);
 ## }
 
@@ -166,6 +166,11 @@ toCairoX11 <- function(name, ...) {
 
 ##############################################################################
 # HISTORY:
+# 2014-08-29
+# o Changed default argument 'field' for toNNN() from "fullname" to
+#   "pathname" as in getOption("devEval/args/field", "pathname").
+#   This should work for most compilers include LaTeX, although in
+#   later it is preferred to use "fullname".
 # 2014-04-28
 # o Waiting with toCairoPNG() and toJavaGD().
 # o Added toDefault(), toX11(), toWindows(), and toQuartz().
